=====
rest_utils
=====

rest_utils is a simple Django app tha that provides resusable utils for a django rest project.

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "rest_utils" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'rest_utils',
    ]

2. Use the resusables in views, and renderers.py files in your project.

